@@ -24,7 +24,6 @@ my $TimeUnit = {
     'm' => 60,                      # Minute,
     's' => 1,                       # Second
 };
-
 my $MathematicalConstant = {
     'e' => CONST_E,
     'p' => CONST_P,
@@ -32,29 +31,17 @@ my $MathematicalConstant = {
 };
 
 my $MonthName = {
-    'full' => [
-        'January', 'February', 'March', 'April', 'May', 'June', 'July', 
-        'August', 'September', 'October', 'November', 'December',
-    ],
-    'abbr' => [
-        'Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun',
-        'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec',
-    ],
+    'full' => [qw|January February March April May June July August September October November December|],
+    'abbr' => [qw|Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec|],
 };
 
 my $DayOfWeek = {
-    'full' => [
-        'Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday',
-        'Friday', 'Saturday',
-    ],
-    'abbr' => ['Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat'],
+    'full' => [qw|Sunday Monday Tuesday Wednesday Thursday Friday Saturday|],
+    'abbr' => [qw|Sun Mon Tue Wed Thu Fri Sat|],
 };
 
 my $HourName = {
-    'full' => [
-        'Midnight', 1, 2, 3, 4, 5, 'Morning', 7, 8, 9, 10, 11, 'Noon',
-        13, 14, 15, 16, 17, 'Evening', 19, 20, 21, 22, 23,
-    ],
+    'full' => [qw|Midnight 1 2 3 4 5 Morning 7 8 9 10 11 Noon 13 14 15 16 17 Evening 19 20 21 22 23|],
     'abbr' => [0..23],
 };
 
@@ -202,13 +189,13 @@ sub to_second {
     my $unitoftime = [keys %$TimeUnit];
     my $mathconsts = [keys %$MathematicalConstant];
 
-    if( $value =~ m/\A(\d+|\d+[.]\d+)([@$unitoftime])?\z/o ) {
+    if( $value =~ /\A(\d+|\d+[.]\d+)([@$unitoftime])?\z/o ) {
         # 1d, 1.5w
         my $n = $1;
         my $u = $2 // 'd';
         $getseconds = $n * $TimeUnit->{ $u };
 
-    } elsif( $value =~ m/\A(\d+|\d+[.]\d+)?([@$mathconsts])([@$unitoftime])?\z/o ) {
+    } elsif( $value =~ /\A(\d+|\d+[.]\d+)?([@$mathconsts])([@$unitoftime])?\z/o ) {
         # 1pd, 1.5pw
         my $n = $1 // 1;
         my $m = $MathematicalConstant->{ $2 } // 0;
@@ -281,7 +268,7 @@ sub o2d {
     my $piece = new Time::Piece;
     my $epoch = 0;
 
-    return $piece->ymd($argv2) unless $argv1 =~ m/\A[-]?\d+\z/;
+    return $piece->ymd($argv2) unless $argv1 =~ /\A[-]?\d+\z/;
 
     $epoch = $piece->epoch - $argv1 * 86400;
     if( $epoch < 0 ) {
@@ -325,7 +312,7 @@ sub parse {
 
     while( my $p = shift @timetokens ) {
         # Parse each piece of time
-        if( $p =~ m/\A[A-Z][a-z]{2}[,]?\z/ ) {
+        if( $p =~ /\A[A-Z][a-z]{2}[,]?\z/ ) {
             # Day of week or Day of week; Thu, Apr, ...
             chop $p if length($p) == 4; # Thu, -> Thu
 
@@ -337,8 +324,7 @@ sub parse {
                 # Month name abbr.; Apr, May, ...
                 $v->{'M'} = $p;
             }
-
-        } elsif( $p =~ m/\A\d{1,4}\z/ ) {
+        } elsif( $p =~ /\A\d{1,4}\z/ ) {
             # Year or Day; 2005, 31, 04,  1, ...
             if( $p > 31 ) {
                 # The piece is the value of an year
@@ -355,9 +341,8 @@ sub parse {
                     $v->{'d'} = $p;
                 }
             }
-
-        } elsif( $p =~ m/\A([0-2]\d):([0-5]\d):([0-5]\d)\z/ ||
-                 $p =~ m/\A(\d{1,2})[-:](\d{1,2})[-:](\d{1,2})\z/ ) {
+        } elsif( $p =~ /\A([0-2]\d):([0-5]\d):([0-5]\d)\z/ ||
+                 $p =~ /\A(\d{1,2})[-:](\d{1,2})[-:](\d{1,2})\z/ ) {
             # Time; 12:34:56, 03:14:15, ...
             # Arrival-Date: 2014-03-26 00-01-19
             if( $1 < 24 && $2 < 60 && $3 < 60 ) {
@@ -365,27 +350,26 @@ sub parse {
                 $v->{'T'} = sprintf("%02d:%02d:%02d", $1, $2, $3);
             }
 
-        } elsif( $p =~ m/\A([0-2]\d):([0-5]\d)\z/ ) {
+        } elsif( $p =~ /\A([0-2]\d):([0-5]\d)\z/ ) {
             # Time; 12:34 => 12:34:00
             if( $1 < 24 && $2 < 60 ) {
                 $v->{'T'} = sprintf("%02d:%02d:00", $1, $2);
             }
-
-        } elsif( $p =~ m/\A(\d\d?):(\d\d?)\z/ ) {
+        } elsif( $p =~ /\A(\d\d?):(\d\d?)\z/ ) {
             # Time: 1:4 => 01:04:00
             $v->{'T'} = sprintf("%02d:%02d:00", $1, $2);
 
-        } elsif( $p =~ m/\A[APap][Mm]\z/ ) {
+        } elsif( $p =~ /\A[APap][Mm]\z/ ) {
             # AM or PM
             $afternoon1 = 1;
 
         } else {
             # Timezone offset and others
-            if( $p =~ m/\A[-+][01]\d{3}\z/ ) {
+            if( $p =~ /\A[-+][01]\d{3}\z/ ) {
                 # Timezone offset; +0000, +0900, -1000, ...
                 $v->{'z'} ||= $p;
 
-            } elsif( $p =~ m/\A[(]?[A-Z]{2,5}[)]?\z/ ) {
+            } elsif( $p =~ /\A[(]?[A-Z]{2,5}[)]?\z/ ) {
                 # Timezone abbreviation; JST, GMT, UTC, ...
                 $v->{'z'} ||= __PACKAGE__->abbr2tz($p) || '+0000';
 
@@ -406,7 +390,6 @@ sub parse {
                     if( $4 < 24 && $5 < 60 && $6 < 60 ) {
                         $v->{'T'} = sprintf("%02d:%02d:%02d", $4, $5, $6);
                     }
-
                 } elsif( $p =~ m|\A(\d{1,2})/(\d{1,2})/(\d{1,2})\z| ) {
                     # 4/29/01 11:34:45 PM
                     $v->{'M'} = $MonthName->{'abbr'}->[int($1) - 1];
@@ -493,7 +476,7 @@ sub tz2second {
     my $class = shift;
     my $argv1 = shift || return undef;
 
-    if( $argv1 =~ m/\A([-+])(\d)(\d)(\d{2})\z/ ) {
+    if( $argv1 =~ /\A([-+])(\d)(\d)(\d{2})\z/ ) {
         my $ztime = 0;
         my $digit = {
             'operator' => $1,
@@ -508,7 +491,7 @@ sub tz2second {
         return undef if abs($ztime) > TZ_OFFSET;
         return $ztime;
 
-    } elsif( $argv1 =~ m/\A[A-Za-z]+\z/ ) {
+    } elsif( $argv1 =~ /\A[A-Za-z]+\z/ ) {
         return __PACKAGE__->tz2second($TimeZoneAbbr->{ $argv1 });
 
     } else {
@@ -589,7 +572,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2017 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2018 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
