@@ -14,18 +14,21 @@ sub match {
     my $class = shift;
     my $argv1 = shift // return undef;
     my $regex = qr{(?>
-         access[ ]denied[.][ ]IP[ ]name[ ]lookup[ ]failed
+         access[ ]denied[.][ ]ip[ ]name[ ]lookup[ ]failed
         |access[ ]from[ ]ip[ ]address[ ].+[ ]blocked
-        |all[ ]mail[ ]servers[ ]must[ ]have[ ]a[ ]PTR[ ]record[ ]with[ ]a[ ]valid[ ]Reverse[ ]DNS[ ]entry
-        |Bad[ ]sender[ ]IP[ ]address
+        |all[ ]mail[ ]servers[ ]must[ ]have[ ]a[ ]ptr[ ]record[ ]with[ ]a[ ]valid[ ]reverse[ ]dns[ ]entry
+        |bad[ ]sender[ ]ip[ ]address
         |blacklisted[ ]by
-        |(?:Blocked|Refused)[ ]-[ ]see[ ]https?://
-        |can[']t[ ]determine[ ]Purported[ ]Responsible[ ]Address
-        |cannot[ ]resolve[ ]your[ ]address
+        |(?:blocked|refused)[ ]-[ ]see[ ]https?://
+        |can[']t[ ]determine[ ]purported[ ]responsible[ ]address
+        |cannot[ ](?:
+             find[ ]your[ ]hostname
+            |resolve[ ]your[ ]address
+            )
         |client[ ]host[ ](?:
              .+[ ]blocked[ ]using
             |rejected:[ ](?:
-                 Abus[ ]detecte[ ]GU_EIB_0[24]      # SFR
+                 abus[ ]detecte[ ]gu_eib_0[24]      # SFR
                 |cannot[ ]find[ ]your[ ]hostname    # Yahoo!
                 |may[ ]not[ ]be[ ]mail[ ]exchanger
                 |was[ ]not[ ]authenticated          # Microsoft
@@ -38,107 +41,107 @@ sub match {
            |reset[ ]by[ ]peer
            |was[ ]dropped[ ]by[ ]remote[ ]host
            )
-        |Connections[ ](?:
-             not[ ]accepted[ ]from[ ]IP[ ]addresses[ ]on[ ]Spamhaus[ ]XBL
-            |will[ ]not[ ]be[ ]accepted[ ]from[ ].+because[ ]the[ ]ip[ ]is[ ]in[ ]Spamhaus's[ ]list
+        |connections[ ](?:
+             not[ ]accepted[ ]from[ ]ip[ ]addresses[ ]on[ ]spamhaus[ ]xbl
+            |will[ ]not[ ]be[ ]accepted[ ]from[ ].+because[ ]the[ ]ip[ ]is[ ]in[ ]spamhaus's[ ]list
             )
-        |Currently[ ]Sending[ ]Spam[ ]See:[ ]
+        |currently[ ]sending[ ]spam[ ]see:[ ]
         |domain[ ](?:
              .+[ ]mismatches[ ]client[ ]ip
             |does[ ]not[ ]exist:
             )
         |dns[ ]lookup[ ]failure:[ ].+[ ]try[ ]again[ ]later
-        |DNSBL:ATTRBL
-        |Dynamic/zombied/spam[ ]IPs[ ]blocked
-        |Email[ ]blocked[ ]by[ ](?:.+[.]barracudacentral[.]org|SPAMHAUS)
-        |Fix[ ]reverse[ ]DNS[ ]for[ ].+
-        |Go[ ]away
-        |host[ ].+[ ]refused[ ]to[ ]talk[ ]to[ ]me:[ ]\d+[ ]Blocked
+        |dnsbl:attrbl
+        |dynamic/zombied/spam[ ]ips[ ]blocked
+        |email[ ]blocked[ ]by[ ](?:.+[.]barracudacentral[.]org|spamhaus)
+        |fix[ ]reverse[ ]dns[ ]for[ ].+
+        |go[ ]away
+        |host[ ].+[ ]refused[ ]to[ ]talk[ ]to[ ]me:[ ]\d+[ ]blocked
         |hosts[ ]with[ ]dynamic[ ]ip
         |http://(?:
              spf[.]pobox[.]com/why[.]html
             |www[.]spamcop[.]net/bl[.]
             )
-        |INVALID[ ]IP[ ]FOR[ ]SENDING[ ]MAIL[ ]OF[ ]DOMAIN
-        |IP[ ]\d{1,3}[.]\d{1,3}[.]\d{1,3}[.]\d{1,3}[ ]is[ ]blocked[ ]by[ ]EarthLink # Earthlink
-        |IP[/]domain[ ]reputation[ ]problems
-        |IPs[ ]with[ ]missing[ ]PTR[ ]records
+        |invalid[ ]ip[ ]for[ ]sending[ ]mail[ ]of[ ]domain
+        |ip[ ]\d{1,3}[.]\d{1,3}[.]\d{1,3}[.]\d{1,3}[ ]is[ ]blocked[ ]by[ ]earthlink # Earthlink
+        |ip[/]domain[ ]reputation[ ]problems
+        |ips[ ]with[ ]missing[ ]ptr[ ]records
         |is[ ](?:
              in[ ]a[ ]black[ ]list[ ]at[ ].+[.]
-            |in[ ]an[ ].*RBL[ ]on[ ].+
+            |in[ ]an[ ].*rbl[ ]on[ ].+
             |not[ ]allowed[ ]to[ ]send[ ](?:
                  mail[ ]from
-                |from[ ].+[ ]per[ ]it's[ ]SPF[ ]Record
+                |from[ ].+[ ]per[ ]it's[ ]spf[ ]record
                 )
             )
         |mail[ ]server[ ]at[ ].+[ ]is[ ]blocked
-        |Mail[ ]from[ ]\d+[.]\d+[.]\d+[.]\d[ ]refused:
-        |Message[ ]from[ ].+[ ]rejected[ ]based[ ]on[ ]blacklist
-        |Messages[ ]from[ ].+[ ]temporarily[ ]deferred[ ]due[ ]to[ ]user[ ]complaints   # Yahoo!
+        |mail[ ]from[ ]\d+[.]\d+[.]\d+[.]\d[ ]refused:
+        |message[ ]from[ ].+[ ]rejected[ ]based[ ]on[ ]blacklist
+        |messages[ ]from[ ].+[ ]temporarily[ ]deferred[ ]due[ ]to[ ]user[ ]complaints   # Yahoo!
         |no[ ](?:
              access[ ]from[ ]mail[ ]server
-            |PTR[ ]Record[ ]found[.]
+            |ptr[ ]record[ ]found[.]
             )
-        |Not[ ]currently[ ]accepting[ ]mail[ ]from[ ]your[ ]ip  # Microsoft
+        |not[ ]currently[ ]accepting[ ]mail[ ]from[ ]your[ ]ip  # Microsoft
         |part[ ]of[ ]their[ ]network[ ]is[ ]on[ ]our[ ]block[ ]list
-        |Please[ ](?:
-             get[ ]a[ ]custom[ ]reverse[ ]DNS[ ]name[ ]from[ ]your[ ]ISP[ ]for[ ]your[ ]host
-            |inspect[ ]your[ ]SPF[ ]settings
-            |use[ ]the[ ]smtp[ ]server[ ]of[ ]your[ ]ISP
+        |please[ ](?:
+             get[ ]a[ ]custom[ ]reverse[ ]dns[ ]name[ ]from[ ]your[ ]isp[ ]for[ ]your[ ]host
+            |inspect[ ]your[ ]spf[ ]settings
+            |use[ ]the[ ]smtp[ ]server[ ]of[ ]your[ ]isp
             )
-        |PTR[ ]record[ ]setup
-        |Rejecting[ ]open[ ]proxy   # Sendmail(srvrsmtp.c)
-        |Reverse[ ]DNS[ ](?:
+        |ptr[ ]record[ ]setup
+        |rejecting[ ]open[ ]proxy   # Sendmail(srvrsmtp.c)
+        |reverse[ ]dns[ ](?:
               failed
              |required
              |lookup[ ]for[ ]host[ ].+[ ]failed[ ]permanently
              )
-        |Sender[ ]IP[ ](?:
+        |sender[ ]ip[ ](?:
              address[ ]rejected
             |reverse[ ]lookup[ ]rejected
             )
-        |Server[ ]access[ ](?:
-             .+[ ]forbidden[ ]by[ ]invalid[ ]RDNS[ ]record[ ]of[ ]your[ ]mail[ ]server
-            |forbidden[ ]by[ ]your[ ]IP[ ]
+        |server[ ]access[ ](?:
+             .+[ ]forbidden[ ]by[ ]invalid[ ]rdns[ ]record[ ]of[ ]your[ ]mail[ ]server
+            |forbidden[ ]by[ ]your[ ]ip[ ]
             )
-        |Server[ ]IP[ ].+[ ]listed[ ]as[ ]abusive
-        |service[ ]permits[ ]\d+[ ]unverifyable[ ]sending[ ]IPs
-        |SMTP[ ]error[ ]from[ ]remote[ ]mail[ ]server[ ]after[ ]initial[ ]connection:   # Exim
+        |server[ ]ip[ ].+[ ]listed[ ]as[ ]abusive
+        |service[ ]permits[ ]\d+[ ]unverifyable[ ]sending[ ]ips
+        |smtp[ ]error[ ]from[ ]remote[ ]mail[ ]server[ ]after[ ]initial[ ]connection:   # Exim
         |sorry,[ ](?:
              that[ ]domain[ ]isn'?t[ ]in[ ]my[ ]list[ ]of[ ]allowed[ ]rcpthosts
             |your[ ]remotehost[ ]looks[ ]suspiciously[ ]like[ ]spammer
             )
-        |SPF[ ](?:
+        |spf[ ](?:
              .+[ ]domain[ ]authentication[ ]fail
             |record
             |check:[ ]fail
             )
-        |SPF:[ ].+[ ]is[ ]not[ ]allowed[ ]to[ ]send[ ]mail.+[A-Z]{3}.+401
+        |spf:[ ].+[ ]is[ ]not[ ]allowed[ ]to[ ]send[ ]mail.+[a-z]{3}.+401
         |the[ ](?:email|domain|ip).+[ ]is[ ]blacklisted
-        |This[ ]system[ ]will[ ]not[ ]accept[ ]messages[ ]from[ ]servers[/]devices[ ]with[ ]no[ ]reverse[ ]DNS
-        |Too[ ]many[ ]spams[ ]from[ ]your[ ]IP  # free.fr
+        |this[ ]system[ ]will[ ]not[ ]accept[ ]messages[ ]from[ ]servers[/]devices[ ]with[ ]no[ ]reverse[ ]dns
+        |too[ ]many[ ]spams[ ]from[ ]your[ ]ip  # free.fr
         |unresolvable[ ]relay[ ]host[ ]name
-        |Veuillez[ ]essayer[ ]plus[ ]tard.+[A-Z]{3}.+(?:103|510)
+        |veuillez[ ]essayer[ ]plus[ ]tard.+[a-z]{3}.+(?:103|510)
         |your[ ](?:
              network[ ]is[ ]temporary[ ]blacklisted
-            |sender's[ ]IP[ ]address[ ]is[ ]listed[ ]at[ ].+[.]abuseat[.]org
+            |sender's[ ]ip[ ]address[ ]is[ ]listed[ ]at[ ].+[.]abuseat[.]org
             |server[ ]requires[ ]confirmation
             )
         |was[ ]blocked[ ]by[ ].+
         |we[ ]do[ ]not[ ]accept[ ]mail[ ]from[ ](?: # @mail.ru
              dynamic[ ]ips
-            |hosts[ ]with[ ]dynamic[ ]IP[ ]or[ ]generic[ ]dns[ ]PTR-records
+            |hosts[ ]with[ ]dynamic[ ]ip[ ]or[ ]generic[ ]dns[ ]ptr-records
             )
-        |You[ ]are[ ](?:
+        |you[ ]are[ ](?:
              not[ ]allowed[ ]to[ ]connect
             |sending[ ]spam
             )
-        |Your[ ](?:
+        |your[ ](?:
              access[ ]to[ ]submit[ ]messages[ ]to[ ]this[ ]e-mail[ ]system[ ]has[ ]been[ ]rejected
             |message[ ]was[ ]rejected[ ]for[ ]possible[ ]spam/virus[ ]content
             )
         )
-    }xi;
+    }x;
 
     return 1 if $argv1 =~ $regex;
     return 0;
@@ -155,24 +158,11 @@ sub true {
     my $argvs = shift // return undef;
 
     return undef unless ref $argvs eq 'Sisimai::Data';
-    return 1 if $argvs->reason eq __PACKAGE__->text;
+    return 1 if $argvs->reason eq 'blocked';
 
     require Sisimai::SMTP::Status;
-    my $statuscode = $argvs->deliverystatus // '';
-    my $diagnostic = $argvs->diagnosticcode // '';
-    my $tempreason = Sisimai::SMTP::Status->name($statuscode);
-    my $reasontext = __PACKAGE__->text;
-    my $v = 0;
-
-    if( $tempreason eq $reasontext ) {
-        # Delivery status code points "blocked".
-        $v = 1;
-
-    } else {
-        # Matched with a pattern in this class
-        $v = 1 if __PACKAGE__->match($diagnostic);
-    }
-    return $v;
+    return 1 if Sisimai::SMTP::Status->name($argvs->deliverystatus) eq 'blocked';
+    return 1 if __PACKAGE__->match(lc $argvs->diagnosticcode);
 }
 
 1;
@@ -227,7 +217,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2017 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2018 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
